import { MaybeLoadingResult } from './loading';
import { Subscribable } from 'sourcegraph';
import { Observable } from 'rxjs';
/**
 * Converts a provider result, which can be a continuously-updating, maybe-loading Subscribable, or a Promise for a
 * single result, to the same type.
 */
export declare const toMaybeLoadingProviderResult: <T>(value: Subscribable<MaybeLoadingResult<T>> | PromiseLike<T>) => Observable<MaybeLoadingResult<T>>;
/**
 * Returns true if `val` is not `null` or `undefined`
 */
export declare const isDefined: <T>(val: T) => val is NonNullable<T>;
/**
 * Returns a function that returns `true` if the given `key` of the object is not `null` or `undefined`.
 *
 * I ❤️ TypeScript.
 */
export declare const propertyIsDefined: <T extends object, K extends keyof T>(key: K) => (val: T) => val is T & { [k in K]-?: NonNullable<T[k]>; };
/**
 * Scrolls an element to the center if it is out of view.
 * Does nothing if the element is in view.
 *
 * @param container The scrollable container (that has `overflow: auto`)
 * @param content The content child that is being scrolled
 * @param target The element that should be scrolled into view
 */
export declare const scrollIntoCenterIfNeeded: (container: HTMLElement, content: HTMLElement, target: HTMLElement) => void;
/**
 * Returns a curried function that returns `true` if `e1` and `e2` overlap.
 */
export declare const elementOverlaps: (e1: HTMLElement) => (e2: HTMLElement) => boolean;
//# sourceMappingURL=helpers.d.ts.map