import { OperatorFunction } from 'rxjs';
export declare const LOADING: "loading";
/**
 * An emission from a result provider.
 *
 * @template T The type of the result. Should typically include an empty value, or even an error type.
 */
export interface MaybeLoadingResult<T> {
    /**
     * Whether the result provider is currently getting a new result.
     */
    isLoading: boolean;
    /**
     * The latest result.
     */
    result: T;
}
/**
 * Maps a stream of MaybeLoadingResult (which contains both results and loading states) to a stream of clear
 * instructions on when to show a loader, results or nothing.
 *
 * @param loaderDelay The delay, in milliseconds, after which a loader should be shown if no results have been emitted.
 * @param emptyResultValue The value that represents the absence of results. This will be emitted, and also deep-compared to with `isEqual()`. Example: `null`, `[]`
 *
 * @template TResult The type of the provider result (without `TEmpty`).
 * @template TEmpty The type of the empty value, e.g. `null` or `[]`.
 */
export declare const emitLoading: <TResult, TEmpty>(loaderDelay: number, emptyResultValue: TEmpty) => OperatorFunction<MaybeLoadingResult<TResult | TEmpty>, "loading" | TResult | TEmpty | undefined>;
//# sourceMappingURL=loading.d.ts.map